﻿using Hotline.Orders;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;

namespace Hotline.Api.Controllers
{
    /// <summary>
    /// 热点
    /// </summary>
    public class HotspotController : BaseController
    {
        private readonly IHotspotTypeRepository _hotspotTypeRepository;

        public HotspotController(IHotspotTypeRepository hotspotTypeRepository)
        {
            _hotspotTypeRepository = hotspotTypeRepository;
        }

        /// <summary>
        /// 查询子项
        /// </summary>
        [HttpGet("children")]
        public async Task<IReadOnlyList<HotSpotType>> GetChildren([FromQuery] string? id)
        {
            return await _hotspotTypeRepository.Queryable()
                .Where(x => x.ParentId == id)
                .OrderBy(d=>d.HotSpotName)
                .ToListAsync();
        }

        /// <summary>
        /// 查询热点数据（包含所有根目录及所查热点的所有上级对象）
        /// <remarks>
        /// 编辑页面使用
        /// </remarks>
        /// </summary>
        /// <param name="id"></param>
        /// <returns></returns>
        [HttpGet("{id}/with-parents")]
        public async Task<IReadOnlyList<HotSpotType>> GetWithParents(string id)
        {
            var targetList = await _hotspotTypeRepository.Queryable()
                .ToTreeAsync(d => d.Children, d => d.ParentId, null, new[] { id });
            var topIds = targetList.Select(d => d.Id);
            var hotspots = await _hotspotTypeRepository.Queryable()
                .Where(d => string.IsNullOrEmpty(d.ParentId) && !topIds.Contains(d.Id))
                .ToListAsync();
            hotspots.AddRange(targetList);
            return hotspots.OrderBy(d=>d.HotSpotName).ToList();
        }
    }
}
