﻿using Hotline.Application.Identity;
using Hotline.Caches;
using Hotline.Settings;
using Hotline.Share.Dtos.Identity;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using XF.Domain.Constants;

namespace Hotline.Api.Controllers;

public class IdentityController : BaseController
{
    private readonly IIdentityAppService _identityAppService;
    private readonly ISystemSettingCacheManager _systemSettingCacheManager;

    public IdentityController(IIdentityAppService identityAppService, ISystemSettingCacheManager systemSettingCacheManager)
    {
        _identityAppService = identityAppService;
        _systemSettingCacheManager  = systemSettingCacheManager;
    }

    /// <summary>
    /// 登录
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [AllowAnonymous]
    [HttpPost("login")]
    public async Task<string> Login([FromBody] LoginDto dto)
    {
        return await _identityAppService.LoginAsync(dto, HttpContext.RequestAborted);
    }

    /// <summary>
    /// 登录页系统配置
    /// </summary>
    /// <returns></returns>
    [AllowAnonymous]
    [HttpGet("login-page-info")]
    public async Task<LoginPageInfoDto> LoginPageInfo()
    {
        var SysName = _systemSettingCacheManager.GetSetting(SettingConstants.SysName).SettingValue;
        var LoginImage = _systemSettingCacheManager.GetSetting(SettingConstants.LoginImage).SettingValue;

        return new LoginPageInfoDto() { SysName = SysName, LoginImage= LoginImage };
    }

}