﻿using Hotline.Settings;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using XF.Domain.Dependency;

namespace Hotline.Permissions
{
    public interface IPermissionManager
    {
        IReadOnlyList<string> RolesToPermissions(List<string> roles);
    }

    public class PermissionManager : IPermissionManager, ISingletonDependency
    {
        private readonly ISystemAuthorityRepository _systemauthorityRepository;

        public PermissionManager(IServiceScopeFactory factory)
        {
            _systemauthorityRepository = factory.CreateScope().ServiceProvider.GetRequiredService<ISystemAuthorityRepository>();
        }


        public IReadOnlyList<string> RolesToPermissions(List<string> roles)
        {
            var list = _systemauthorityRepository.GetPermission(roles);

            return list.Select(x => Enum.Parse(typeof(EPermission), x).ToString()).ToList();
        }
    }
}
