﻿using Hotline.Caches;
using Hotline.CallCenter.Calls;
using Hotline.Share.Notifications;
using MediatR;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Hotline.Application.Handlers.CallCenter.CallState
{
    public class AlertExtToExtNotificationHandler : INotificationHandler<AlertExtToExtNotification>
    {
        private readonly ICallRepository _callRepository;
        private readonly ICallDetailRepository _callDetailRepository;
        private readonly IUserCacheManager _userCacheManager;

        public AlertExtToExtNotificationHandler(ICallRepository callRepository,ICallDetailRepository callDetailRepository,IUserCacheManager userCacheManager)
        {
            _callRepository = callRepository;
            _callDetailRepository = callDetailRepository;
            _userCacheManager = userCacheManager;
        }

        public async Task Handle(AlertExtToExtNotification notification, CancellationToken cancellationToken)
        {
            var workModel = _userCacheManager.GetWorkByTel(notification.FromTelNo);
            if (workModel is not null)
            {
                var callModel = new Call()
                {
                    CallStatus = Share.Enums.CallCenter.ECallStatus.Alert,
                    CallDirection = Share.Enums.CallCenter.ECallDirection.Out,
                    CallType = Share.Enums.CallCenter.ECallType.ExtToExt,
                    FromNo = notification.FromTelNo,
                    ToNo = notification.ToTelNo,
                    UserId = workModel.UserId,
                    UserName = workModel.UserName,
                    PhoneIsp = Share.Enums.CallCenter.EPhoneISP.NULL,
                };
                callModel.Modified();
                var callId = await _callRepository.AddAsync(callModel, cancellationToken);
                //写入明细
                var detail = new CallDetail()
                {
                    CallId = callId,
                    CallStatus = Share.Enums.CallCenter.ECallStatus.Alert,
                    EventName = "Alert",
                    FromNo = notification.FromTelNo,
                    ToNo = notification.ToTelNo,
                };
                await _callDetailRepository.AddAsync(detail, cancellationToken);
            }
        }
    }
}
