﻿using Hotline.Caches;
using Hotline.CallCenter.Calls;
using Hotline.Realtimes;
using Hotline.Share.Notifications;
using MediatR;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Hotline.Application.Handlers.CallCenter.CallState
{
    public class RingExtToExtNotificationHandler : INotificationHandler<RingExtToExtNotification>
    {
        private readonly ICallRepository _callRepository;
        private readonly ICallDetailRepository _callDetailRepository;
        private readonly IRealtimeService _realtimeService;
        private readonly IUserCacheManager _userCacheManager;


        public RingExtToExtNotificationHandler(ICallRepository callRepository,ICallDetailRepository callDetailRepository,IRealtimeService realtimeService,IUserCacheManager userCacheManager)
        {
            _callRepository = callRepository;
            _callDetailRepository = callDetailRepository;
            _realtimeService = realtimeService;
            _userCacheManager = userCacheManager;
        }


        public async Task Handle(RingExtToExtNotification notification, CancellationToken cancellationToken)
        {
            var model = await _callRepository.GetAsync(x=>x.FromNo == notification.FromTelNo && x.ToNo== notification.ToTelNo && x.CallStatus == Share.Enums.CallCenter.ECallStatus.Alert && x.CreationTime >= DateTime.Now.AddHours(-1),true,x=>x.CreationTime, cancellationToken);
            if (model!=null)
            {
                model.CallStatus = Share.Enums.CallCenter.ECallStatus.Ring;
                model.RingTime = DateTime.Now;
                await _callRepository.UpdateAsync(model,cancellationToken);
                var detail = new CallDetail()
                {
                    CallId = model.Id,
                    CallStatus = Share.Enums.CallCenter.ECallStatus.Ring,
                    EventName = notification.Attribute,
                    FromNo = notification.FromTelNo,
                    ToNo = notification.ToTelNo,
                };
                await _callDetailRepository.AddAsync(detail,cancellationToken);

                //通知前端主叫
                //获取主叫工作信息
                var fromWork = _userCacheManager.GetWorkByTel(notification.FromTelNo);
                if (fromWork!=null)
                {
                    await _realtimeService.RingAsync(fromWork.UserId, new Share.Dtos.Realtime.RingDto() { Id = model.Id, From = notification.FromTelNo, To = notification.ToTelNo, CallType = Share.Enums.CallCenter.ECallType.ExtToExt }, cancellationToken);
                }
                //通知前端被叫
                var toWork = _userCacheManager.GetWorkByTel(notification.ToTelNo);
                if (toWork!=null)
                {
                    await _realtimeService.RingAsync(toWork.UserId, new Share.Dtos.Realtime.RingDto() { Id = model.Id, From = notification.FromTelNo, To = notification.ToTelNo, CallType = Share.Enums.CallCenter.ECallType.ExtToExt }, cancellationToken);
                }
            }
        }
    }
}
