﻿using Hotline.Caches;
using Hotline.CallCenter.Calls;
using Hotline.Share.Enums.CallCenter;
using Hotline.Share.Notifications;
using MediatR;

namespace Hotline.Application.Handlers.CallCenter.CallState
{
    public class RingExtToOuterNotificationHandler:INotificationHandler<RingExtToOuterNotification>
    {
        private readonly ICallRepository _callRepository;
        private readonly ICallDetailRepository _callDetailRepository;
        private readonly IUserCacheManager _userCacheManager;

        public RingExtToOuterNotificationHandler(ICallRepository callRepository, ICallDetailRepository callDetailRepository,IUserCacheManager userCacheManager)
        {
            _callRepository = callRepository;
            _callDetailRepository = callDetailRepository;
            _userCacheManager = userCacheManager;
        }

        public async Task Handle(RingExtToOuterNotification notification, CancellationToken cancellationToken)
        {
            var model = await _callRepository.GetAsync(x =>
                x.FromNo == notification.TelNo && x.ToNo == notification.Outer.To && x.CreationTime >=DateTime.Now.AddHours(-2),true,x=>x.CreationTime, cancellationToken);
            if (model==null)
            {
                model = await _callRepository.GetAsync(
                    x => x.ConversationId == notification.Outer.Id && x.ToNo == notification.Outer.To &&
                         x.Trunk == notification.Outer.Trunk,true,x=>x.CreationTime, cancellationToken);
            }
                       
            if (model!=null)
            {
                var workModel = _userCacheManager.GetWorkByTel(notification.TelNo);
                model.UserId = workModel.UserId;
                model.UserName = workModel.UserName;
                model.CallStatus = ECallStatus.Ring;
                await _callRepository.UpdateAsync(model, cancellationToken);
                var detail = new CallDetail()
                {
                    CallId = model.Id,
                    CallStatus = ECallStatus.Ring,
                    EventName = notification.Attribute,
                    ConversationId = notification.Outer.Id,
                    OMCallId = notification.Outer.CallId,
                    FromNo = notification.Outer.From,
                    ToNo = notification.Outer.To,
                };
                if (string.IsNullOrEmpty(detail.FromNo))
                    detail.FromNo = notification.TelNo;

                await _callDetailRepository.AddAsync(detail, cancellationToken);
            }
        }
    }
}
