﻿using Hotline.CallCenter.Calls;
using Hotline.Realtimes;
using Hotline.Share.Notifications;
using MediatR;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Hotline.Application.Handlers.CallCenter.FlowControl
{
    public class AnsweredExtToExtNotificationHandler : INotificationHandler<AnsweredExtToExtNotification>
    {
        private readonly ICallRepository _callRepository;
        private readonly ICallDetailRepository _callDetailRepository;
        private readonly IRealtimeService _realtimeService;

        public AnsweredExtToExtNotificationHandler(ICallRepository callRepository,ICallDetailRepository callDetailRepository,IRealtimeService realtimeService)
        {
            _callRepository = callRepository;
            _callDetailRepository = callDetailRepository;
            _realtimeService = realtimeService;
        }

        public async Task Handle(AnsweredExtToExtNotification notification, CancellationToken cancellationToken)
        {
            var model = await _callRepository.GetAsync(x => x.FromNo == notification.FromTelNo && x.ToNo == notification.ToTelNo && x.CreationTime >= DateTime.Now.AddHours(-1), true, x => x.CreationTime, cancellationToken);
            if (model!=null)
            {
                model.CallStatus = Share.Enums.CallCenter.ECallStatus.Answered;
                model.AnsweredTime = DateTime.Now;
                await _callRepository.UpdateAsync(model, cancellationToken);
                var detail = new CallDetail()
                {
                    CallId = model.Id,
                    CallStatus = Share.Enums.CallCenter.ECallStatus.Answered,
                    EventName = notification.Attribute,
                    AnswerNo = notification.ToTelNo,
                    FromNo = notification.FromTelNo, 
                    ToNo = notification.ToTelNo,
                };
                await _callDetailRepository.AddAsync(detail, cancellationToken);
            }
        }
    }
}
