﻿using Hotline.CallCenter.Calls;
using Hotline.Share.Notifications;
using MediatR;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Hotline.Application.Handlers.CallCenter.FlowControl
{
    public class ByeExtAndExtNotificationHandler : INotificationHandler<ByeExtAndExtNotification>
    {
        private readonly ICallRepository _callRepository;
        private readonly ICallDetailRepository _callDetailRepository;

        public ByeExtAndExtNotificationHandler(ICallRepository callRepository,ICallDetailRepository callDetailRepository)
        {
            _callRepository = callRepository;
            _callDetailRepository = callDetailRepository;
        }

        public async Task Handle(ByeExtAndExtNotification notification, CancellationToken cancellationToken)
        {
            var model = await _callRepository.GetAsync(x => x.FromNo == notification.FromTelNo && x.ToNo == notification.ToTelNo && x.CallStatus == Share.Enums.CallCenter.ECallStatus.Answered && x.CreationTime >= DateTime.Now.AddHours(-1),true,x=>x.CreationTime, cancellationToken);
            if (model!=null)
            {
                model.CallStatus = Share.Enums.CallCenter.ECallStatus.Bye;
                model.EndBy = Share.Enums.CallCenter.EEndBy.From;
                model.RingOffType = Share.Enums.CallCenter.ERingOffType.Normal;
                model.ByeTime = DateTime.Now;
                await _callRepository.UpdateAsync(model,cancellationToken);
                var detail = new CallDetail()
                {
                    CallId = model.Id,
                    CallStatus = Share.Enums.CallCenter.ECallStatus.Bye,
                    EventName = notification.Attribute,
                    FromNo = notification.FromTelNo,
                    ToNo = notification.ToTelNo,
                    Recording = notification.Recording,
                };
            }
        }
    }
}
