﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Hotline.Application.FlowEngine;
using Hotline.FlowEngine.Notifies;
using Hotline.Orders;
using Hotline.Settings;
using Hotline.Share.Enums.Order;
using MediatR;
using XF.Domain.Exceptions;

namespace Hotline.Application.Handlers.FlowEngine
{
    public class StartWorkflowHandler : INotificationHandler<StartWorkflowNotify>
    {
        private readonly IWorkflowApplication _workflowApplication;
        private readonly IOrderDomainService _orderDomainService;
        private readonly IOrderRepository _orderRepository;

        public StartWorkflowHandler(
            IWorkflowApplication workflowApplication,
            IOrderDomainService orderDomainService,
            IOrderRepository orderRepository
            )
        {
            _workflowApplication = workflowApplication;
            _orderDomainService = orderDomainService;
            _orderRepository = orderRepository;
        }

        /// <summary>Handles a notification</summary>
        /// <param name="notification">The notification</param>
        /// <param name="cancellationToken">Cancellation token</param>
        public async Task Handle(StartWorkflowNotify notification, CancellationToken cancellationToken)
        {
            var workflow = notification.Workflow;
            var data = notification.Dto;
            var assignMode = await _workflowApplication.GetFlowAssignModeAsync(notification.StepDefine,
                data.NextHandlers.Select(d => d.Id).ToList(), cancellationToken);

            switch (workflow.ModuleCode)
            {
                case WorkflowModuleConsts.OrderManage:
                    await _orderDomainService.OrderManageAsync(EOrderStatus.WaitForSign, assignMode,
                        false, notification.IsCountersignStart,
                        workflow.Id, workflow.CurrentStepTime, workflow.CurrentStepName, workflow.ExpiredTime, cancellationToken);
                    break;
            }
        }
    }
}
