﻿using Hotline.CallCenter.BlackLists;
using Hotline.FlowEngine.Definitions;
using Hotline.FlowEngine.Workflows;
using Hotline.Identity.Roles;
using Hotline.Orders;
using Hotline.Share.Dtos.CallCenter;
using Hotline.Share.Dtos.FlowEngine;
using Hotline.Share.Dtos.Order;
using Hotline.Share.Dtos.Roles;
using Hotline.Share.Dtos.Users;
using Hotline.Users;
using Mapster;

namespace Hotline.Application.Mappers
{
    public class MapperConfigs : IRegister
    {
        public void Register(TypeAdapterConfig config)
        {
            config.ForType<AddBlacklistDto, Blacklist>()
                .Ignore(d => d.Expired)
                .AfterMapping((s, t) => t.InitExpired());

            config.ForType<AddUserDto, User>()
                .Map(d => d.Name, x => x.Name ?? x.UserName);

            config.NewConfig<User, UserDto>()
                .Map(d => d.UserName, x => x.Account.UserName)
                .Map(d => d.OrgName, x => x.Organization.OrgName)
                .Map(d => d.Roles, x => string.Join(',', x.Account.Roles.Select(d => d.DisplayName)))
                .Map(d => d.State, x => x.IsDeleted ? "已删除" : "正常")
                .IgnoreIf((s, d) => s.Account == null, d => d.UserName)
                .IgnoreIf((s, d) => s.Account == null, d => d.Roles)
                ;

            config.NewConfig<Role, RoleDto>()
                .Map(d => d.AccountIds, x => x.Accounts.Select(d => d.Id))
                .Map(d => d.State, x => x.IsDeleted ? "已删除" : "正常");

            #region workflow

            config.ForType<UpdateDefinitionDto, Definition>()
                .Ignore(d => d.Id);

            config.ForType<WorkflowStep, WorkflowStep>()
                .Ignore(d => d.Id);

            #endregion

            #region order

            config.ForType<Order, OrderDto>()
                .IgnoreIf((s, d) => s.OrderComplain == null, d => d.OrderComplain)
                .IgnoreIf((s, d) => s.OrderReport == null, d => d.OrderReport)
                .IgnoreIf((s, d) => s.Employee == null, d => d.EmployeeName, d => d.EmployeeStaffNo)
                .Map(d => d.EmployeeName, x => x.Employee.Name)
                .Map(d => d.EmployeeStaffNo, x => x.Employee.StaffNo)
                ;

            #endregion
        }
    }
}
