﻿using Hotline.Share.Enums.FlowEngine;
using XF.Utility.EnumExtensions;

namespace Hotline.Share.Dtos.FlowEngine
{
    public class WorkflowDto
    {
        public string Id { get; set; }

        public string Title { get; set; }

        /// <summary>
        /// 到期时间
        /// </summary>
        public DateTime ExpiredTime { get; set; }
        
        public DateTime? CompleteTime { get; set; }

        /// <summary>
        /// 当前节点名称（会签状态此字段保存最外层会签办理节点名称）
        /// </summary>
        public string CurrentStepName { get; set; }

        /// <summary>
        /// 到达当前节点时间（stepBox创建时间）
        /// </summary>
        public DateTime CurrentStepTime { get; set; }
        
        public EWorkflowStatus Status { get; set; }

        public DefinitionDto Definition { get; set; }

        /// <summary>
        /// 主节点，依据流转进度动态生成
        /// </summary>
        public List<StepBoxDto> StepBoxes { get; set; }
        
        public List<WorkflowTraceDto> Traces { get; set; }

        public List<WorkflowSupplementDto> Supplements { get; set; }

    }

    public class StepBoxDto
    {
        public DateTime? StartTime { get; set; }

        public DateTime? EndTime { get; set; }

        public List<StepBasicDto> Steps { get; set; }
    }

    public class WorkflowTraceDto : StepBasicDto
    {
        public string WorkflowId { get; set; }

        public string StepId { get; set; }

        public NextWorkflowDto NextWorkflowDto { get; set; }

        public bool IsBackward { get; set; }

        public DateTime? CreationTime { get; set; }
    }

    public class WorkflowSupplementDto
    {
        /// <summary>
        /// 补充意见
        /// </summary>
        public string Opinion { get; set; }

        /// <summary>
        /// 附件
        /// </summary>
        public List<string> Additions { get; set; } = new();
    }
}
