﻿using Hotline.Share.Enums.Order;
using SqlSugar;
using XF.Domain.Repository;

namespace Hotline.Orders;

public class OrderExtensionEntity : FullStateEntity
{
    #region 投诉人信息

    /// <summary>
    /// 证件类型
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? LicenceTypeCode { get; set; }

    [SugarColumn(IsNullable = true)]
    public string? LicenceType { get; set; }

    /// <summary>
    /// 证件号码, 证件类型已选的情况为必填，否则非必填
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? LicenceNo { get; set; }

    /// <summary>
    /// 提供方身份类型
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? IdentityTypeCode { get; set; }

    [SugarColumn(IsNullable = true)]
    public string? IdentityType { get; set; }

    /// <summary>
    /// 提供方身份（投诉人身份）
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? IdentityCode { get; set; }

    [SugarColumn(IsNullable = true)]
    public string? Identity { get; set; }

    /// <summary>
    /// 国籍或地区
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? NationalityCode { get; set; }

    [SugarColumn(IsNullable = true)]
    public string? Nationality { get; set; }

    /// <summary>
    /// 民族
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? NationCode { get; set; }

    [SugarColumn(IsNullable = true)]
    public string? Nation { get; set; }

    /// <summary>
    /// 邮政编码
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? PostalCode { get; set; }

    /// <summary>
    /// 邮箱
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? Email { get; set; }

    /// <summary>
    /// 其他联系方式
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? OtherContact { get; set; }

    #endregion

    #region 投诉对象信息

    /// <summary>
    /// 企业名称
    /// </summary>
    public string EnterpriseName { get; set; }

    /// <summary>
    /// 统一社会信用代码
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? UnifiedSocialCreditCode { get; set; }

    /// <summary>
    /// 注册地址
    /// </summary>
    public string RegisterAddress { get; set; }

    /// <summary>
    /// 注册号
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? RegisterNumber { get; set; }

    /// <summary>
    /// 企业联系人
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? EnterpriseContact { get; set; }

    /// <summary>
    /// 市场主体类型
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? MarketTypeCode { get; set; }

    [SugarColumn(IsNullable = true)]
    public string? MarketType { get; set; }

    /// <summary>
    /// 行业分类
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? IndustryClassifyCode { get; set; }
    [SugarColumn(IsNullable = true)]
    public string? IndustryClassify { get; set; }

    #endregion

    #region 投诉/举报 详情


    /// <summary>
    /// 商品分类/品牌
    /// </summary>
    public string BrandCode { get; set; }

    public string Brand { get; set; }

    /// <summary>
    /// 消费金额，只能填写数字，且只能填写非负数
    /// </summary>
    public decimal Amount { get; set; }

    /// <summary>
    /// 客体类别
    /// </summary>
    public string ObjectClassifyCode { get; set; }

    public string ObjectClassify { get; set; }

    /// <summary>
    /// 销售方式
    /// </summary>
    public string SalesModeCode { get; set; }
    public string SalesMode { get; set; }

    /// <summary>
    /// 电商平台，销售方式为“网购”时展示该字段且必填
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? ECommercePlatformCode { get; set; }

    [SugarColumn(IsNullable = true)]
    public string? ECommercePlatform { get; set; }

    /// <summary>
    /// 外部订单号，销售方式为“ 网购”时展示该字段且必填
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? ExternalOrderNo { get; set; }

    /// <summary>
    /// 具体渠道
    /// <remarks>
    /// 销售方式为“电视购物”“电话购物”“邮购”时展示该字段，且必填
    /// 电视购物：请填写购物的电视频道
    /// 电话购物：请填写商品销售者的热线号码
    /// 邮购：请填写宣传商品的邮政公司或来件地址
    /// </remarks>
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? Channel { get; set; }

    /// <summary>
    /// 专利权人，“投诉问题类别”为“专利”时展示该字段，选填
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? Patentee { get; set; }

    /// <summary>
    /// 专利名称，“投诉问题类别”为“专利”时展示该字段，选填
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? PatentName { get; set; }

    /// <summary>
    /// 专利类型，“投诉问题类别”为“专利”时展示该字段，选填
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? PatentTypeCode { get; set; }

    [SugarColumn(IsNullable = true)]
    public string? PatentType { get; set; }

    /// <summary>
    /// 专利号，“投诉问题类别”为“专利”时展示该字段，选填
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? PatentNo { get; set; }

    /// <summary>
    /// 产品名称
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? ProductName { get; set; }

    /// <summary>
    /// 批准文号
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? ApprovalNumber { get; set; }

    /// <summary>
    /// 产品批号
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? ProductBatchNo { get; set; }

    /// <summary>
    /// 产品规格
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? ProductStandard { get; set; }

    /// <summary>
    /// 产品有效期
    /// </summary>
    public DateTime ProductExpiredTime { get; set; }

    /// <summary>
    /// 生产厂家
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? Manufacturer { get; set; }

    /// <summary>
    /// 销售企业
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? SalesEnterprise { get; set; }

    /// <summary>
    /// 消费者地址
    /// </summary>
    [SugarColumn(IsNullable = true)]
    public string? ConsumerAddress { get; set; }

    #endregion
}