﻿using System.ComponentModel;
using Hotline.Identity.Accounts;
using Hotline.Identity.Roles;
using Hotline.Settings;
using Hotline.Share.Enums.Order;
using SqlSugar;
using XF.Domain.Entities;
using XF.Domain.Repository;

namespace Hotline.Users
{
    /// <summary>
    /// 用户
    /// </summary>
    [Description("用户")]
    public class User : CreationSoftDeleteEntity
    {
        /// <summary>
        /// 手机号(冗余)
        /// </summary>
        [SugarColumn(IsNullable = true)]
        public string? PhoneNo { get; set; }

        /// <summary>
        /// 展示名称(Identity.DisplayName)
        /// </summary>
        public string Name { get; set; }

        public EGender Gender { get; set; }

        /// <summary>
        /// 工号
        /// </summary>
        [SugarColumn(IsNullable = true)]
        public string? StaffNo { get; set; }

        /// <summary>
        /// 部门Id
        /// </summary>
        [SugarColumn(IsNullable = true)]
        public string? OrgId { get; set; }

        /// <summary>
        /// 部门编码（冗余）
        /// </summary>
        [SugarColumn(IsNullable = true)]
        public string? OrgCode { get; set; }

        /// <summary>
        /// 默认分机号
        /// </summary>
        [SugarColumn(IsNullable = true)]
        public string? DefaultTelNo { get; set; }

        /// <summary>
        /// 所属部门
        /// </summary>

        [Navigate(NavigateType.OneToOne, nameof(OrgId))]
        public SystemOrganize Organization { get; set; }

        [Navigate(NavigateType.OneToOne, nameof(Id))]
        public Account Account { get; set; }
    }
}
